@@ -18,7 +18,7 @@ from .entry import *
 from . import icons
 
 
-__autoindex__ = "__autoindex__"
+__autoindex__ = '__autoindex__'
 
 
 class AutoIndex(object):
@@ -28,7 +28,7 @@ class AutoIndex(object):
     example::
 
         app = Flask(__name__)
-        idx = AutoIndex(app, "/home/someone/public_html", add_url_rules=True)
+        idx = AutoIndex(app, '/home/someone/public_html', add_url_rules=True)
 
     :param base: a flask application
     :param browse_root: a path which is served by root address.
@@ -38,23 +38,26 @@ class AutoIndex(object):
     :param **silk_options: keyword options for :class:`flaskext.silk.Silk`
     """
 
+    shared = None
+
     def _register_shared_autoindex(self, state=None, app=None):
         """Registers a magic module named __autoindex__."""
         app = app or state.app
-        if __autoindex__ not in app.modules:
-            shared_mod = Module(__name__)
-            AutoIndex(shared_mod)
-            app.modules[__autoindex__] = shared_mod
+        if __autoindex__ not in app.blueprints:
+            template_folder = os.path.join(__path__[0], 'templates')
+            type(self).shared = Blueprint(__autoindex__, __name__,
+                                          template_folder=template_folder)
+            app.register_blueprint(type(self).shared)
 
     def __new__(cls, base, *args, **kwargs):
         if isinstance(base, Flask):
             return object.__new__(AutoIndexApplication)
-        elif isinstance(base, Module):
-            return object.__new__(AutoIndexModule)
+        elif isinstance(base, Blueprint):
+            return object.__new__(AutoIndexBlueprint)
         else:
-            raise TypeError("'base' should be Flask or Module.")
+            raise TypeError("'base' should be Flask or Blueprint.")
 
-    def __init__(self, base, browse_root=None, add_url_rules=False,
+    def __init__(self, base, browse_root=None, add_url_rules=True,
                  **silk_options):
         """Initializes an autoindex instance."""
         self.base = base
@@ -62,17 +65,18 @@ class AutoIndex(object):
             self.rootdir = RootDirectory(browse_root, autoindex=self)
         else:
             self.rootdir = None
+        silk_options['silk_path'] = silk_options.get('silk_path', '/__icons__')
         self.silk = Silk(self.base, **silk_options)
         self.icon_map = []
         self.converter_map = []
         if add_url_rules:
-            @self.base.route("/")
-            @self.base.route("/<path:path>")
-            def autoindex(path="."):
+            @self.base.route('/')
+            @self.base.route('/<path:path>')
+            def autoindex(path='.'):
                 return self.render_autoindex(path)
 
     def render_autoindex(self, path, browse_root=None, template=None,
-                         endpoint="autoindex"):
+                         endpoint='autoindex'):
         """Renders an autoindex with the given path.
 
         :param path: the relative path
@@ -85,11 +89,11 @@ class AutoIndex(object):
             rootdir = RootDirectory(browse_root, autoindex=self)
         else:
             rootdir = self.rootdir
-        path = re.sub("\/*$", "", path)
+        path = re.sub(r'\/*$', '', path)
         abspath = os.path.join(rootdir.abspath, path)
         if os.path.isdir(abspath):
-            sort_by = request.args.get("sort_by", "name")
-            order = {"asc": 1, "desc": -1}[request.args.get("order", "asc")]
+            sort_by = request.args.get('sort_by', 'name')
+            order = {'asc': 1, 'desc': -1}[request.args.get('order', 'asc')]
             curdir = Directory(path, rootdir)
             entries = curdir.explore(sort_by=sort_by, order=order)
             if callable(endpoint):
@@ -99,10 +103,10 @@ class AutoIndex(object):
             if template:
                 return render_template(template, **context)
             try:
-                template = "{0}autoindex.html".format(self.template_prefix)
+                template = '{0}autoindex.html'.format(self.template_prefix)
                 return render_template(template, **context)
             except TemplateNotFound as e:
-                template = "{0}/autoindex.html".format(__autoindex__)
+                template = '{0}/autoindex.html'.format(__autoindex__)
                 return render_template(template, **context)
         elif os.path.isfile(abspath):
             return send_file(abspath)
@@ -122,7 +126,7 @@ class AutoIndex(object):
 
                 def has_long_name(ent):
                     return len(ent.name) > 10
-                idx.add_icon_rule("brick.png", rule=has_log_name)
+                idx.add_icon_rule('brick.png', rule=has_log_name)
 
             Now the application represents files or directorys such as
             ``very-very-long-name.js`` with ``brick.png`` icon.
@@ -130,20 +134,20 @@ class AutoIndex(object):
         `ext`
             A file extension or file extensions to match with a file::
 
-                idx.add_icon_rule("ruby.png", ext="ruby")
-                idx.add_icon_rule("bug.png", ext=["bug", "insect"])
+                idx.add_icon_rule('ruby.png', ext='ruby')
+                idx.add_icon_rule('bug.png', ext=['bug', 'insect'])
 
         `mimetype`
             A mimetype or mimetypes to match with a file::
 
-                idx.add_icon_rule("application.png", mimetype="application/*")
-                idx.add_icon_rule("world.png", mimetype=["image/icon", "x/*"])
+                idx.add_icon_rule('application.png', mimetype='application/*')
+                idx.add_icon_rule('world.png', mimetype=['image/icon', 'x/*'])
 
         `name`
             A name or names to match with a file or directory::
 
-                idx.add_icon_rule("error.png", name="error")
-                idx.add_icon_rule("database.png", name=["mysql", "sqlite"])
+                idx.add_icon_rule('error.png', name='error')
+                idx.add_icon_rule('database.png', name=['mysql', 'sqlite'])
 
         `filename`
             Same as `name`, but it matches only a file.
@@ -156,9 +160,9 @@ class AutoIndex(object):
         url dynamically. Here's a nice example::
 
             def get_favicon(ent):
-                favicon = "favicon.ico"
+                favicon = 'favicon.ico'
                 if type(ent) is Directory and favicon in ent:
-                    return "/" + os.path.join(ent.path, favicon)
+                    return '/' + os.path.join(ent.path, favicon)
                 return False
             idx.add_icon_rule(get_favicon)
 
@@ -186,11 +190,11 @@ class AutoIndex(object):
         static directory first. If it failed to find the file, it finds from
         the wrapped application or module's static directory.
         """
-        global_static = os.path.join(os.path.dirname(__file__), "static")
+        global_static = os.path.join(os.path.dirname(__file__), 'static')
         if os.path.isfile(os.path.join(global_static, filename)):
             static = global_static
         else:
-            static = os.path.join(self.base.root_path, "static")
+            static = os.path.join(self.base.root_path, 'static')
         return send_from_directory(static, filename)
 
     @property
@@ -200,25 +204,38 @@ class AutoIndex(object):
 
 class AutoIndexApplication(AutoIndex):
 
-    template_prefix = ""
+    template_prefix = ''
 
     def __init__(self, app, browse_root=None, **silk_options):
         super(AutoIndexApplication, self).__init__(app, browse_root,
                                                    **silk_options)
         self.app = app
-        self.app.view_functions["static"] = self.send_static_file
+        self.app.view_functions['static'] = self.send_static_file
         self._register_shared_autoindex(app=self.app)
 
 
-class AutoIndexModule(AutoIndex):
+class AutoIndexBlueprint(AutoIndex):
 
-    def __init__(self, mod, browse_root=None, **silk_options):
-        super(AutoIndexModule, self).__init__(mod, browse_root, **silk_options)
-        self.mod = self.base
-        self.mod._record(self._register_shared_autoindex)
-        self.mod.send_static_file = self.send_static_file
+    def __init__(self, blueprint, browse_root=None, **silk_options):
+        super(AutoIndexBlueprint, self).__init__(blueprint, browse_root,
+                                                 **silk_options)
+        self.blueprint = self.base
+        self.blueprint.record_once(self._register_shared_autoindex)
+        self.blueprint.send_static_file = self.send_static_file
 
     @cached_property
     def template_prefix(self):
-        return self.mod.name + "/"
+        return self.blueprint.name + '/'
 
+
+class AutoIndexModule(AutoIndexBlueprint):
+
+    def __init__(self, *args, **kwargs):
+        import warnings
+        warnings.warn('AutoIndexModule is deprecated; ' \
+                      'use AutoIndexBlueprint instead.', DeprecationWarning)
+        super(AutoIndexModule, self).__init__(*args, **kwargs)
+
+    @property
+    def mod(self):
+        return self.blueprint
